import setuptools

setuptools.setup(
    name='symphonaipy',  
    version='0.2',
    author="Sven Schultze",
    author_email="schultze.sven@googlemail.com",
    description="A tool to communicate within symphonai",
    long_description="long_description",
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[

    ]
)
